@@ -363,7 +363,7 @@ class Project(SquadObject):
         return self.slug
 
     @staticmethod
-    def compare_builds(baseline_id, build_id, force=False):
+    def compare_builds(baseline_id, build_id, by="tests", force=False):
         try:
             int(baseline_id)
             int(build_id)
@@ -376,7 +376,7 @@ class Project(SquadObject):
             if proj_id != to_compare.project.split("/")[-2]:
                 raise InvalidSquadLookup("Argument builds must belong to same project")
             url = ''.join([Project.endpoint, str(proj_id), '/compare_builds'])
-            params = {'baseline': baseline_id, 'to_compare': build_id}
+            params = {'baseline': baseline_id, 'to_compare': build_id, 'by': by}
             if force:
                 params['force'] = '1'
             return SquadApi.get(url, params).json()
