@@ -1,3 +1,4 @@
+import logging
 from unittest import TestCase
 
 
@@ -61,14 +62,21 @@ class SubmitResultsShortcutTest(TestCase):
             "testb": {"result": "pass", "log": "the log"},
         }
         metrics = {"metrica": 42}
-        success = submit_results(
-            group_project_slug="my_group/my_project",
-            build_version="my_build",
-            env_slug="my_env",
-            tests=tests,
-            metrics=metrics,
-            metadata=metadata,
-        )
+
+        with self.assertLogs(logger='squad_client.core.models', level=logging.ERROR) as cm:
+            success = submit_results(
+                group_project_slug="my_group/my_project",
+                build_version="my_build",
+                env_slug="my_env",
+                tests=tests,
+                metrics=metrics,
+                metadata=metadata,
+            )
+
+            self.assertIn(
+                'ERROR:squad_client.core.models:Failed to submit results: There is already a test run with job_id 12345',
+                cm.output
+            )
 
         results = self.squad.tests(name="test-malformed")
         self.assertTrue(len(results) == 0)
